/***************************************************************************//**
 * @file sl_wisun_alliance_certificates.h
 * @brief Certificates for Wi-SUN FAN certification
 *******************************************************************************
 * # License
 * <b>Copyright 2022 Silicon Laboratories Inc. www.silabs.com</b>
 *******************************************************************************
 *
 * SPDX-License-Identifier: Zlib
 *
 * The licensor of this software is Silicon Laboratories Inc.
 *
 * This software is provided 'as-is', without any express or implied
 * warranty. In no event will the authors be held liable for any damages
 * arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any purpose,
 * including commercial applications, and to alter it and redistribute it
 * freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must not
 *    claim that you wrote the original software. If you use this software
 *    in a product, an acknowledgment in the product documentation would be
 *    appreciated but is not required.
 * 2. Altered source versions must be plainly marked as such, and must not be
 *    misrepresented as being the original software.
 * 3. This notice may not be removed or altered from any source distribution.
 *
 ******************************************************************************/

#ifndef SL_WISUN_ALLIANCE_CERTIFICATES_H
#define SL_WISUN_ALLIANCE_CERTIFICATES_H

#include <stdint.h>

const uint8_t WISUN_ALLIANCE_ROOT_CERTIFICATE[] = {
    "-----BEGIN CERTIFICATE-----\r\n"
    "MIIBojCCAUmgAwIBAgIFAPf29t8wCgYIKoZIzj0EAwIwMTEOMAwGA1UECgwFV2lT\r\n"
    "VU4xEzARBgNVBAMMCldpU1VOIFJvb3QxCjAIBgNVBAUTATEwIBcNMTcwNzA0MjEw\r\n"
    "NDAyWhgPOTk5OTEyMzEyMzU5NTlaMDExDjAMBgNVBAoMBVdpU1VOMRMwEQYDVQQD\r\n"
    "DApXaVNVTiBSb290MQowCAYDVQQFEwExMFkwEwYHKoZIzj0CAQYIKoZIzj0DAQcD\r\n"
    "QgAEVrJidrjt1nWFVA/VOA/1XKARMBv9t+9XbnErRKJhwudMEUguImA6Ns5TS6o6\r\n"
    "wDDGjYF6JzO1htL1+MTNFkId+KNMMEowDwYDVR0TAQH/BAUwAwEB/zARBgNVHQ4E\r\n"
    "CgQIQP089aoIBgswDgYDVR0PAQH/BAQDAgEGMBQGA1UdIAEB/wQKMAgwBgYEVR0g\r\n"
    "ADAKBggqhkjOPQQDAgNHADBEAiBYqSiYL0Tu8D/zzU8TajVkzKMw6qkku+UIezPn\r\n"
    "2Tv6rAIgP5+YwqTLC9QTfuz2/XN6Ta5Hd4zgyLSvc1BXm94r06k=\r\n"
    "-----END CERTIFICATE-----\r\n"
    "-----BEGIN CERTIFICATE-----\r\n"
    "MIICTzCCAfSgAwIBAgIEGAcYATAKBggqhkjOPQQDAjB1MQswCQYDVQQGEwJCRTEZ\r\n"
    "MBcGA1UEChMQR2xvYmFsU2lnbiBudi1zYTEaMBgGA1UECxMRRm9yIFRlc3QgVXNl\r\n"
    "IE9ubHkxLzAtBgNVBAMTJkdsb2JhbFNpZ24gV2ktU1VOIEZBTiBFQ0MgVGVzdCBS\r\n"
    "b290IENBMCAXDTE4MDcxODAwMDAwMFoYDzk5OTkxMjMxMjM1OTU5WjB/MQswCQYD\r\n"
    "VQQGEwJCRTEZMBcGA1UEChMQR2xvYmFsU2lnbiBudi1zYTEaMBgGA1UECxMRRm9y\r\n"
    "IFRlc3QgVXNlIE9ubHkxOTA3BgNVBAMTMEdsb2JhbFNpZ24gV2ktU1VOIEZBTiBF\r\n"
    "Q0MgVGVzdCBNYW51ZmFjdHVyZXIgQ0EgMTBZMBMGByqGSM49AgEGCCqGSM49AwEH\r\n"
    "A0IABELV4UWWmobdLAWUmawJqMV6/IbCTwEyAAuuj3zhYunZsLFJq7oThLf8S8l8\r\n"
    "+L19ActTDTcE40dRamCjtgpyG7ejZjBkMA4GA1UdDwEB/wQEAwICBDASBgNVHRMB\r\n"
    "Af8ECDAGAQH/AgEBMB0GA1UdDgQWBBSB8SepzJmMBati+8zAm50esXEhqzAfBgNV\r\n"
    "HSMEGDAWgBQ9KneAKRkrEUlMBJxb/XyMmJx/kjAKBggqhkjOPQQDAgNJADBGAiEA\r\n"
    "yDZk9pKX8O3xYIURThYWG3dcS2kOIdKuP2tJ4nwMG4UCIQCzRPcY8jAjLqThArsB\r\n"
    "K+Sc8kKdRCayEfN0cJyGVTjGmw==\r\n"
    "-----END CERTIFICATE-----\r\n"
    "-----BEGIN CERTIFICATE-----\r\n"
    "MIICIDCCAcagAwIBAgIBATAKBggqhkjOPQQDAjB1MQswCQYDVQQGEwJCRTEZMBcG\r\n"
    "A1UEChMQR2xvYmFsU2lnbiBudi1zYTEaMBgGA1UECxMRRm9yIFRlc3QgVXNlIE9u\r\n"
    "bHkxLzAtBgNVBAMTJkdsb2JhbFNpZ24gV2ktU1VOIEZBTiBFQ0MgVGVzdCBSb290\r\n"
    "IENBMCAXDTE4MDcxODAwMDAwMFoYDzk5OTkxMjMxMjM1OTU5WjB1MQswCQYDVQQG\r\n"
    "EwJCRTEZMBcGA1UEChMQR2xvYmFsU2lnbiBudi1zYTEaMBgGA1UECxMRRm9yIFRl\r\n"
    "c3QgVXNlIE9ubHkxLzAtBgNVBAMTJkdsb2JhbFNpZ24gV2ktU1VOIEZBTiBFQ0Mg\r\n"
    "VGVzdCBSb290IENBMFkwEwYHKoZIzj0CAQYIKoZIzj0DAQcDQgAEp5HbQNUb1bW4\r\n"
    "LnUfs77YXysSp+fXXomez+pnzXIb4FJP94knwauyoMd99BsmW/fK/yHzk6Rs4Fma\r\n"
    "T5m7eRpll6NFMEMwDgYDVR0PAQH/BAQDAgIEMBIGA1UdEwEB/wQIMAYBAf8CAQIw\r\n"
    "HQYDVR0OBBYEFD0qd4ApGSsRSUwEnFv9fIyYnH+SMAoGCCqGSM49BAMCA0gAMEUC\r\n"
    "IQDjD8vQ8PbGY+MCP5e4PW0O0ValmtnVg4DXoGYRz+tioQIgGpHT7NmOHtEg4HRG\r\n"
    "BJe60OcyxFjpDsp/R2pGArN9iuE=\r\n"
    "-----END CERTIFICATE-----\r\n"
    "-----BEGIN CERTIFICATE-----\r\n"
    "MIICXjCCAgOgAwIBAgIEGAcYAjAKBggqhkjOPQQDAjB/MQswCQYDVQQGEwJCRTEZ\r\n"
    "MBcGA1UEChMQR2xvYmFsU2lnbiBudi1zYTEaMBgGA1UECxMRRm9yIFRlc3QgVXNl\r\n"
    "IE9ubHkxOTA3BgNVBAMTMEdsb2JhbFNpZ24gV2ktU1VOIEZBTiBFQ0MgVGVzdCBN\r\n"
    "YW51ZmFjdHVyZXIgQ0EgMTAgFw0xODA3MTgwMDAwMDBaGA85OTk5MTIzMTIzNTk1\r\n"
    "OVowgYMxCzAJBgNVBAYTAkJFMRkwFwYDVQQKExBHbG9iYWxTaWduIG52LXNhMRow\r\n"
    "GAYDVQQLExFGb3IgVGVzdCBVc2UgT25seTE9MDsGA1UEAxM0R2xvYmFsU2lnbiBX\r\n"
    "aS1TVU4gRkFOIEVDQyBUZXN0IFN1Yi1NYW51ZmFjdHVyZXIgQ0EgMTBZMBMGByqG\r\n"
    "SM49AgEGCCqGSM49AwEHA0IABEtsbzInynM0ddFwhBMlrZF/b8QJOS8rR6Ji4aSq\r\n"
    "8fIjK+9cyMPTwnxaCSZUvj+IjqM1fcossLTcvQJTGr8ZiRajZjBkMA4GA1UdDwEB\r\n"
    "/wQEAwICBDASBgNVHRMBAf8ECDAGAQH/AgEAMB0GA1UdDgQWBBQ3ttkOUJkFBUV3\r\n"
    "L09XhhFkvRu9vDAfBgNVHSMEGDAWgBSB8SepzJmMBati+8zAm50esXEhqzAKBggq\r\n"
    "hkjOPQQDAgNJADBGAiEAv3SUEAVVEVbu5LIAP9IC7bgM3nZFLXsCCqK/NvifL+8C\r\n"
    "IQC0IkpgzHopVq84LtxKr8gnIp8rnsIRUTL53Go2LbQ3PQ==\r\n"
    "-----END CERTIFICATE-----\r\n"
    "-----BEGIN CERTIFICATE-----\r\n"
    "MIIB4TCCAYigAwIBAgIEUNvhVjAKBggqhkjOPQQDAjBRMQswCQYDVQQGEwJDSDEQ\r\n"
    "MA4GA1UECgwHV0lTZUtleTEkMCIGA1UEAwwbV0lTZUtleSBXaVNVTiBSb290IDIw\r\n"
    "MjEwMjExMQowCAYDVQQFEwExMCAXDTIxMDIxMjAwMzA0N1oYDzk5OTkxMjMxMjM1\r\n"
    "OTU5WjBRMQswCQYDVQQGEwJDSDEQMA4GA1UECgwHV0lTZUtleTEkMCIGA1UEAwwb\r\n"
    "V0lTZUtleSBXaVNVTiBSb290IDIwMjEwMjExMQowCAYDVQQFEwExMFkwEwYHKoZI\r\n"
    "zj0CAQYIKoZIzj0DAQcDQgAEYkxjJ3qNGLbbHZFJN/nM62XM+dS6F4SLBtuGeLCP\r\n"
    "iL9asvMxntr8NYMRZyr887dC6k+OldJOf+eMGg9caRpMJaNMMEowDwYDVR0TAQH/\r\n"
    "BAUwAwEB/zAUBgNVHSABAf8ECjAIMAYGBFUdIAAwDgYDVR0PAQH/BAQDAgEGMBEG\r\n"
    "A1UdDgQKBAhJVH7jDHAAnTAKBggqhkjOPQQDAgNHADBEAiAxjZjxXqQllKX1k63g\r\n"
    "r6MW8voGCcIGB5geIbZuTv1bsAIgDajKaMJVdmPo9w0/QX5Ybxb58/luR+oMi34V\r\n"
    "+HBMCEc=\r\n"
    "-----END CERTIFICATE-----\r\n"
    "-----BEGIN CERTIFICATE-----\r\n"
    "MIIB9jCCAZ2gAwIBAgIEGNO7GzAKBggqhkjOPQQDAjBRMQswCQYDVQQGEwJDSDEQ\r\n"
    "MA4GA1UECgwHV0lTZUtleTEkMCIGA1UEAwwbV0lTZUtleSBXaVNVTiBSb290IDIw\r\n"
    "MjEwMjExMQowCAYDVQQFEwExMCAXDTIxMDIxMjAxMDUwMloYDzk5OTkxMjMxMjM1\r\n"
    "OTU5WjBIMQswCQYDVQQGEwJDSDEQMA4GA1UECgwHV0lTZUtleTEbMBkGA1UEAwwS\r\n"
    "V2lTVU4gTUNBIDIwMjEwMjExMQowCAYDVQQFEwEyMFkwEwYHKoZIzj0CAQYIKoZI\r\n"
    "zj0DAQcDQgAE63SiAdB48/cF7HXFf+he4fkHsViCKFmA+MRaDq++6scvcvw6v+CB\r\n"
    "09f33blbqevs0U34Ye9NjrGtHvRLNlIiwqNqMGgwEgYDVR0TAQH/BAgwBgEB/wIB\r\n"
    "ATATBgNVHSMEDDAKgAhJVH7jDHAAnTAaBgNVHSABAf8EEDAOMAwGCisGAQQBguQl\r\n"
    "AQEwDgYDVR0PAQH/BAQDAgIEMBEGA1UdDgQKBAhN0Gt6xVF2MzAKBggqhkjOPQQD\r\n"
    "AgNHADBEAiBhM2L6DhbCrxfBGeYENQpVAiJ5FNFaohLPQ3Zwp9UbtAIge6U17XtC\r\n"
    "StkMaibYRbNq5aSh+H1gsOrFkqU7e1bsZ4M=\r\n"
    "-----END CERTIFICATE-----\r\n"
    "-----BEGIN CERTIFICATE-----\r\n"
    "MIIB7zCCAZWgAwIBAgIEVPqn5zAKBggqhkjOPQQDAjBIMQswCQYDVQQGEwJDSDEQ\r\n"
    "MA4GA1UECgwHV0lTZUtleTEbMBkGA1UEAwwSV2lTVU4gTUNBIDIwMjEwMjExMQow\r\n"
    "CAYDVQQFEwEyMCAXDTIxMDIxMjAxMjcwOVoYDzk5OTkxMjMxMjM1OTU5WjBJMQsw\r\n"
    "CQYDVQQGEwJDSDEQMA4GA1UECgwHV0lTZUtleTEcMBoGA1UEAwwTV2lTVU4gTUlD\r\n"
    "QSAyMDIxMDIxMTEKMAgGA1UEBRMBMzBZMBMGByqGSM49AgEGCCqGSM49AwEHA0IA\r\n"
    "BJ0g9pXvlCDkVclUVc7w9KXBK0iyjruiU7YnlWg3ZUiXw3MotIKd0gM2OPpzUp7I\r\n"
    "3u4NnJYrZggnQJpkyQYpSfijajBoMBIGA1UdEwEB/wQIMAYBAf8CAQAwEwYDVR0j\r\n"
    "BAwwCoAITdBresVRdjMwGgYDVR0gAQH/BBAwDjAMBgorBgEEAYLkJQEBMA4GA1Ud\r\n"
    "DwEB/wQEAwICBDARBgNVHQ4ECgQISP7nvtFWv9UwCgYIKoZIzj0EAwIDSAAwRQIg\r\n"
    "dJBbQiCF5+hKSUP6NpoKfjWmcym+TcL1wG6GGKfBEG4CIQDZer5G2+D3lpNoGVZO\r\n"
    "68JOxZXtWcYkNj39u5bfKJPSUg==\r\n"
    "-----END CERTIFICATE-----"
};

const uint8_t WISUN_ALLIANCE_SERVER_CERTIFICATE[] = {
    "-----BEGIN CERTIFICATE-----\r\n"
    "MIIBnDCCAUGgAwIBAgIESmUozDAKBggqhkjOPQQDAjAxMQ4wDAYDVQQKDAVXaVNV\r\n"
    "TjETMBEGA1UEAwwKV2lTVU4gUm9vdDEKMAgGA1UEBRMBMTAgFw0xNzA4MjEwMDA0\r\n"
    "MjBaGA85OTk5MTIzMTIzNTk1OVowADBZMBMGByqGSM49AgEGCCqGSM49AwEHA0IA\r\n"
    "BEcZ97gqqNcjNLKzMlnRbl7XWlNFZ1+42QsCBAWEAR8g9nRo9KiTnq//DdLcT8Vl\r\n"
    "afcK82gf3GMjf3nNUy1jbCOjdjB0MBMGA1UdIwQMMAqACED9PPWqCAYLMA4GA1Ud\r\n"
    "DwEB/wQEAwIDiDAqBgNVHREBAf8EIDAeoBwGCCsGAQUFBwgEoBAwDgYIKwYBBAEJ\r\n"
    "AQMEAgIiMCEGA1UdJQEB/wQXMBUGCSsGAQQBguQlAQYIKwYBBQUHAwEwCgYIKoZI\r\n"
    "zj0EAwIDSQAwRgIhAMeYoELP41Sre9ZQdotZAJLnOCcLyd5Q98OIRieX4JeBAiEA\r\n"
    "vXfGcPH4OxN5WNop7gF5BKjqnWpgdHvrsUK1kQNbKPI=\r\n"
    "-----END CERTIFICATE-----"
};

const uint8_t WISUN_ALLIANCE_SERVER_KEY[] = {
    "-----BEGIN PRIVATE KEY-----\r\n"
    "MIGHAgEAMBMGByqGSM49AgEGCCqGSM49AwEHBG0wawIBAQQgOEY66Wi9AgjQpcBx\r\n"
    "0kQRwE7auj6CjWQnstUoiUxMpGuhRANCAARHGfe4KqjXIzSyszJZ0W5e11pTRWdf\r\n"
    "uNkLAgQFhAEfIPZ0aPSok56v/w3S3E/FZWn3CvNoH9xjI395zVMtY2wj\r\n"
    "-----END PRIVATE KEY-----"
};

const uint8_t WISUN_ALLIANCE_CLIENT_CERTIFICATE[] = {
    "-----BEGIN CERTIFICATE-----\r\n"
    "MIIBoTCCAUegAwIBAgIEDnpQ4DAKBggqhkjOPQQDAjAxMQ4wDAYDVQQKDAVXaVNV\r\n"
    "TjETMBEGA1UEAwwKV2lTVU4gUm9vdDEKMAgGA1UEBRMBMTAgFw0yMDEwMTkxMjU0\r\n"
    "MTVaGA85OTk5MTIzMTIzNTk1OVowADBZMBMGByqGSM49AgEGCCqGSM49AwEHA0IA\r\n"
    "BPxiIsSFZ+hZyc1zXwIJ/BkFk6vkX/ES0DGtPF0hMa3m+IbHtJ4S+yLjRqjUFtiT\r\n"
    "+hddjZ9vnmjBrADP4jOm1eajfDB6MBMGA1UdIwQMMAqACED9PPWqCAYLMA4GA1Ud\r\n"
    "DwEB/wQEAwIDiDAwBgNVHREBAf8EJjAkoCIGCCsGAQUFBwgEoBYwFAYHKwYBBAEq\r\n"
    "AgQJNDQwMDYyMjA2MCEGA1UdJQEB/wQXMBUGCSsGAQQBguQlAQYIKwYBBQUHAwIw\r\n"
    "CgYIKoZIzj0EAwIDSAAwRQIhAI7E5SvsunNbiEYCgsBCuE+DrSUeLmoxqviD/3Ao\r\n"
    "yG4IAiAOuxqlnC7NwvJam08NDL2IsvKCfv55jYZ+6N7irn2Txw==\r\n"
    "-----END CERTIFICATE-----"
};

const uint8_t WISUN_ALLIANCE_CLIENT_KEY[] = {
    "-----BEGIN PRIVATE KEY-----\r\n"
    "MIGHAgEAMBMGByqGSM49AgEGCCqGSM49AwEHBG0wawIBAQQg70ivhK5pop2ebhBI\r\n"
    "A+VmVkn4u//w4Ty6pOD9lmLlgOqhRANCAAT8YiLEhWfoWcnNc18CCfwZBZOr5F/x\r\n"
    "EtAxrTxdITGt5viGx7SeEvsi40ao1BbYk/oXXY2fb55owawAz+IzptXm\r\n"
    "-----END PRIVATE KEY-----"
};

#endif /* SL_WISUN_ALLIANCE_CERTIFICATES_H */
